@@ -6,8 +6,12 @@ CHINA_TZ = timezone("Asia/Shanghai")
 
 
 SQLITE_PATH_RR_PC = "/mnt/f/Stock/iwencai/"
+
 SQLITE_PATH_ALIYUN = "/mnt/disk1/sqlit_data/"
-PATH_ALIYUN = "/mnt/disk1/iwencai/"
+PATH_WSL_IWENCAI =  "/mnt/f/Stock/iwencai/"
+
+PATH_ALIYUN_IWENCAI = "/mnt/disk1/stock/iwencai/"
+PATH_VPS_IWENCAI = "$HOME/data/iwencai/"
 
 MAX_QUERY_SIZE: int = 6000
 WC_DATE_FORMATE: str = '%Y-%m-%d'
